@@ -1,9 +1,16 @@
 from django.db import models
-from django.contrib.auth.models import User
 from django.core.urlresolvers import reverse
 from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
 
+# support custom user models in django 1.5+
+# https://docs.djangoproject.com/en/1.5/topics/auth/customizing/#substituting-a-custom-user-model
+try:
+    from django.contrib.auth import get_user_model
+except ImportError:
+    from django.contrib.auth.models import User
+else:
+    User = get_user_model()
 
 class Announcement(models.Model):
     """
